@@ -97,19 +97,19 @@ class Log(DatLog, UsrLog):
             if self.pk is None:
                 self.usr_insercao = request_.user.id if request_ is not None else None
                 self.dat_insercao = timezone.now()
-                self.origem_insercao_codigo = request_.user.tipo_codigo if request_ is not None else None
+                self.origem_insercao_codigo = request_.user.tipo_codigo if request_ is not None and request_.user.id is not None else None
                 self.status = True
             else:
                 self.usr_edicao = request_.user.id if request_ is not None else None
                 self.dat_edicao = timezone.now()
-                self.origem_codigo_codigo = request_.user.tipo_codigo if request_ is not None else None
+                self.origem_codigo_codigo = request_.user.tipo_codigo if request_ is not None and request_.user.id is not None else None
         super(Log, self).save(*args, **kwargs)
 
     def desabilitar(self, request_=None, *args, **kwargs):
         self.status = False
         self.usr_delete_id = request_.user.id if request_ is not None else None
         self.dat_delete = timezone.now()
-        self.origem_delete_codigo = request_.user.tipo_codigo if request_ is not None else None
+        self.origem_delete_codigo = request_.user.tipo_codigo if request_ is not None and request_.user.id is not None else None
         super(Log, self).save(*args, **kwargs)
 
 
