@@ -1,15 +1,16 @@
-from django.contrib.auth.base_user import AbstractBaseUser
+from django.contrib.auth.base_user import AbstractBaseUser, BaseUserManager
 from django.db import models
 from django.utils import timezone
 
 import core.models
-from django.contrib.auth.models import AbstractUser
+from django.contrib.auth.models import UserManager
 from compositefk.fields import CompositeForeignKey
 
 
 class Profile(AbstractBaseUser, core.models.Log):
     username = models.CharField(max_length=200, unique=True)
     USERNAME_FIELD = 'username'
+    objects = BaseUserManager()
 
     tipo_codigo = models.CharField(null=True, max_length=200)
     tipo_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
@@ -19,7 +20,7 @@ class Profile(AbstractBaseUser, core.models.Log):
     })
 
     origem_codigo = models.CharField(null=True, max_length=200)
-    origem_tipo = models.CharField(null=True, max_length=200, default='USR.ORIGEM')
+    origem_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
     origem = CompositeForeignKey(core.models.Tipo, on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_origem', to_fields={
         "codigo": "origem_codigo",
         "tipo": "origem_tipo"
@@ -46,7 +47,7 @@ class GrupoUser(core.models.Log):
 
     usr_id = models.IntegerField(null=True)
     usr_codigo = models.CharField(null=True, max_length=200)
-    usr_tipo = models.CharField(null=True, max_length=200, default='USR.ORIGEM')
+    usr_tipo = models.CharField(null=True, max_length=200, default='USR.PROFILE')
     usr = CompositeForeignKey('core.Tipo', on_delete=models.DO_NOTHING, null=True, related_name='%(app_label)s_%(class)s_usr', to_fields={
         "codigo": "usr_codigo",
         "tipo": "usr_tipo"
